#ifndef _PATHS_H
#define _PATHS_H

#define _PATH_BSHELL "/bin/sh"
#define _PATH_DEFPATH "/bin:/usr/bin:"

#define _PATH_DEVNULL "/dev/null"

#define _PATH_CONSOLE "/dev/console"

#define _PATH_PASSWD "/etc/passwd"
#define _PATH_GROUP "/etc/group"
#define _PATH_SHADOW "/etc/shadow"

#define	_PATH_SHELLS	"/etc/shells"

#define _PATH_VARRUN	"/var/run/"

/* puke */
#define _PATH_MAILDIR	"/var/mail"

#define _PATH_TTY	"/dev/tty"
#define _PATH_MNTTAB	"/etc/fstab"
#define _PATH_MOUNTED	"/etc/mtab"
#define	_PATH_DEV	"/dev/"

#define _PATH_TMP	"/tmp/"

#endif
